#!/bin/python3
import os
import sys

from dataclasses import dataclass
from enum import Enum

from .api_methods import logger

# Path Info 
class PATH_UTILS(Enum):
    SCRIPT_DIR = "scripts/"
    SCRIPT_BUID = "build.sh"
    SCRIPT_COMMIT = "commit.sh"
    SCRIPT_PUSH = "push.sh"
    SCRIPT_CLEAN = "clean.sh"
    LIB_NAME = "tf"

@dataclass
class CLI_Utils():
    def __init__(self) -> None:
        """ Search for PATH lib. """
        self.path = None
                
        # Searching for lib dir
        start = sys.path
        for x in reversed(range(len(start))):
            tmp_path = os.path.join(start[x], PATH_UTILS.LIB_NAME.value)

            if os.path.exists(tmp_path):
                self.path = tmp_path
                break
        
        if self.path is None:
            raise Exception("Path file not found. Program cannot be used. Make sure the program is installed properly.")
        
        # logger.info(f"Program's PATH is at {self.path}")
        # os.chdir(self.path) # updating CWD to PATH's lib not local
        self.script_path = os.path.realpath( os.path.join(self.path, PATH_UTILS.SCRIPT_DIR.value) )

    def build(self) -> None:
        logger.info("Build is running...")
        self.__exe__(script_name=PATH_UTILS.SCRIPT_BUID.value)
                         
    def commit(self) -> None:
        logger.info("Commit is running...")
        self.__exe__(script_name=PATH_UTILS.SCRIPT_COMMIT.value)

    def push(self) -> None:
        logger.info("Push is running...")
        self.__exe__(script_name=PATH_UTILS.SCRIPT_PUSH.value)

    def clean(self) -> None:
        logger.info("Clean is running...")
        self.__exe__(script_name=PATH_UTILS.SCRIPT_CLEAN.value)

    def __exe__(self, script_name) -> None:
        tmp_path = os.path.realpath( os.path.join(self.script_path, script_name) )

        if os.path.exists(tmp_path):
            os.system(tmp_path)
        else:
            logger.error("Internal Error: Path does not exist")




#!/bin/python3

import click

from .api_methods import logger
from .cli_utils import CLI_Utils

# To create args for each option, replace is_flag with 
# type=(<data_type1>, <data_type2>, ...) function in each option  
@click.command()
@click.option("-b", "--build", is_flag=True, help="Test and fmt .tf code.")
@click.option("-c", "--commit", is_flag=True, help="Make commits to local repo.")
@click.option("-p", "--push", is_flag=True, help="Push tf data to server.")
@click.option("-c", "--clean", is_flag=True, help="Clean unnecessary tf files.")
def main(build, commit, push, clean) -> int:
    try:
        CLI = CLI_Utils()
    except Exception as err:
        logger.error(err)
    else:
        if build:
            CLI.build()
        
        elif commit:
            CLI.commit()
        
        elif push:
            CLI.push()
        
        elif clean:
            CLI.clean()
    return 0


if __name__ == '__main__':
    main()
